@@ -97,6 +97,9 @@ class PMSA0031(Hardware):
     sda = models.IntegerField()
     reset = models.IntegerField()
 
+class AM2315(Hardware):
+    scl = models.IntegerField()
+    sda = models.IntegerField()
 
 class HardwareChannelTypes(models.Model):
     hardware_type = models.CharField(
@@ -133,6 +136,10 @@ class Channel(models.Model):
         VEML7700Light = 'VEML7700Light'
         VEML7700Lux = 'VEML7700Lux'
         PiRelay = 'PiRelay'
+        AM2315Humidity = 'AM2315Humidity'
+        AM2315Temperature = 'AM2315Temperature'
+        PMSA003125 = 'PMSA003125'
+        PMSA0031100 = 'PMSA0031100'
 
     id = models.UUIDField(primary_key=True, default=uuid.uuid4)
     channel_index = models.IntegerField(null=True)
